#
# spec file for package python3-virtualenv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python3-virtualenv
Version:        20.17.1
Release:        150600.1.2
Summary:        Virtual Python Environment builder
License:        MIT
Group:          Development/Languages/Python
URL:            http://www.virtualenv.org/
Source:         https://files.pythonhosted.org/packages/source/v/virtualenv/virtualenv-%{version}.tar.gz
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module importlib_resources}
BuildRequires:  %{python_module filelock}
BuildRequires:  %{python_module distlib}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  python-rpm-macros
BuildRequires:  fdupes
Requires:       python3
Requires:       python3-setuptools
Requires:       python3-distlib
Requires:       python3-filelock
Requires:       python3-platformdirs
Requires:       python3-importlib-metadata
Requires:       python3-importlib_resources
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
virtualenv is a tool to create isolated Python environments.
The basic problem being addressed is one of dependencies and versions, and
indirectly permissions. Imagine you have an application that needs version 1
of LibFoo, but another application requires version 2.

Or more generally, what if you want to install an application and leave it be?
If an application works, any change in its libraries or the versions of those
libraries can break the application.

Also, what if you cant install packages into the global site-packages
directory? For instance, on a shared host.

In all these cases, virtualenv can help you. It creates an environment that
has its own installation directories, that doesnt share libraries with other
virtualenv environments (and optionally doesnt use the globally installed
libraries either).

%prep
%autosetup -p1 -n virtualenv-%{version}

# Dependencies on all those shells are too cumbersome.
rm -r tests/unit/activation

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/virtualenv

%check
export LANG="en_US.UTF8"
export PIP_CERT="%{_sysconfdir}/ssl/ca-bundle.pem"
export PYTHONPATH=$PWD/src
# online tests downloads from pypi
donttest="test_seed_link_via_app_data"
# gh#pypa/virtualenv!2431
donttest+=" or test_py_pyc_missing"
# No pytest-freezegun dependency
donttest+=" or test_get_wheel_download_cached"
donttest+=" or test_periodic_update_skip"
donttest+=" or test_periodic_update_trigger"
donttest+=" or test_do_update_first"
donttest+=" or test_do_update_skip_already_done"
donttest+=" or test_download_stop_with_embed"
donttest+=" or test_download_manual_stop_after_one_download"
donttest+=" or test_download_manual_ignores_pre_release"
donttest+=" or test_download_periodic_stop_at_first_usable"
donttest+=" or test_download_periodic_stop_at_first_usable_with_previous_minor"

# test broken upstream https://github.com/pypa/virtualenv/issues/530
%python_expand py.test-%{$python_bin_suffix} -k "not ($donttest)" -vv
%post
%python_install_alternative virtualenv

%postun
%python_uninstall_alternative virtualenv

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/virtualenv
%{python_sitelib}/virtualenv-%{version}*-info
%python_alternative %{_bindir}/virtualenv

%changelog
* Wed Nov 22 2023 daniel.garcia@suse.com
- Update to v20.17.1 (jsc#PED-7278)
  * A py or python spec means any Python rather than CPython.
  * Make activate.nu respect VIRTUAL_ENV_DISABLE_PROMPT
    and not set the prompt if reqeusted.
- from v20.17.0
  * Change Nushell activation script to be a module meant to be
    activated as an overlay.
  * Update operator used in Nushell activation script to be
    compatible with future versions.
  * Do not use deprecated API from importlib.resources on Python 3.10 or later.
  * Upgrade embedded setuptools to 65.6.3 from 65.5.1.
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Fri Mar 17 2023 pgajdos@suse.com
- python-six is not required
* Wed Jan 11 2023 steven.kowalik@suse.com
- Add python_module devel to BuildRequires in the test flavor, since
  the test suite checks if the include path exists.
* Sat Dec  3 2022 yarunachalam@suse.com
- Update to version 20.16.7
  * Use parent directory of python executable for pyvenv.cfg “home” value per PEP 405 - by @vfazio. (#2440)
  * In POSIX virtual environments, try alternate binary names if sys._base_executable does not exist - by @vfazio. (#2442)
  * Upgrade embedded wheel to 0.38.4 and pip to 22.3.1 from 22.3 and setuptools to 65.5.1 from 65.5.0
* Tue Oct 25 2022 mcepl@suse.com
- Update to 20.16.6:
  - Drop unneeded shims for PyPy3 directory structure
  - Fix selected scheme on debian derivatives for python 3.10
    when python3-distutils is not installed or the venv scheme is
    not avaiable
  - Allow the test suite to pass even with the original C shell
    (rather than tcsh)
  - Fix fallback handling of downloading wheels for bundled
    packages
  - Upgrade embedded setuptools to 65.5.0 from 65.3.0 and pip to
    22.3 from 22.2.2
* Mon Oct 10 2022 mcepl@suse.com
- Update to vesion 20.16.5:
  - Do not turn echo off for subsequent commands in batch
    activators (activate.bat and deactivate.bat)
  - Bump embed setuptools to 65.3
  - Upgrade embedded pip to 22.2.2 from 22.2.1 and setuptools to
    63.4.1 from 63.2.0
  - Bump embeded pip from 22.2 to 22.2.1
  - Update Nushell activation scripts to version 0.67
  - Drop support for running under Python 2 (still can generate
    Python 2 environments)
  - Upgrade embedded pip to 22.2 from 22.1.2 and setuptools to
    63.2.0 from 62.6.0
* Sat Jul  9 2022 arun@gmx.de
- update to version 20.15.1:
  * Bugfixes
    + Fix the incorrect operation when setuptools plugins output
    something into stdout. (#2335)
    + CPython3Windows creator ignores missing DLLs dir. (#2368)
- changes from version 20.15.0:
  * Features
    + Support for Windows embeddable Python package: includes
    python<VERSION>.zip in the creator sources - by
    @reksarka. (#1774)
  * Bugfixes
    + Upgrade embedded setuptools to 62.3.3 from 62.6.0 and pip to
    22.1.2 from 22.0.4 - by @gaborbernat. (#2348)
    + Use shlex.quote instead of deprecated pipes.quote in Python 3 -
    by @frenzymadness. (#2351)
    + Fix Windows PyPy 3.6 - by @reksarka. (#2363)
* Sat Jun  4 2022 arun@gmx.de
- update to version 20.14.1:
  * Features
    + Support for creating a virtual environment from a Python 2.7
    framework on macOS 12 - by @nickhutchinson. (#2284)
  * Bugfixes
    + Upgrade embedded setuptools to 62.1.0 from 61.0.0 - by
    @gaborbernat. (#2327)
- changes from version 20.14.0:
  * Features
    + Support Nushell activation scripts with nu version 0.60 - by
    @kubouch. (#2321)
  * Bugfixes
    + Upgrade embedded setuptools to 61.0.0 from 60.10.0 - by
    @gaborbernat. (#2322)
- changes from version 20.13.4:
  * Bugfixes
    + Improve performance of python startup inside created virtualenvs
  - by @asottile. (#2317)
    + Upgrade embedded setuptools to 60.10.0 from 60.9.3 - by
    @gaborbernat. (#2320)
* Sat Mar 12 2022 arun@gmx.de
- update to version 20.13.3:
  * Avoid symlinking the contents of /usr into PyPy3.8+ virtualenvs -
    by @stefanor. (#2310)
  * Bump embed pip from 22.0.3 to 22.0.4 - by @gaborbernat. (#2311)
- changes from version 20.13.2:
  * Upgrade embedded setuptools to 60.9.3 from 60.6.0 - by
    @gaborbernat. (#2306)
* Mon Feb  7 2022 dmueller@suse.com
- update to 20.13.1:
  * fix “execv() arg 2 must contain only strings” error on M1 MacOS
  * Ugrade embedded setuptools to 60.5.0 from 60.2.0
  * Upgrade embedded pip to 22.0.3 and setuptools to 60.6.0
* Sat Jan 29 2022 arun@gmx.de
- specfile:
  * update copyright year
- update to version 20.13.0:
  * Features
    + Add downloaded wheel information in the relevant JSON embed file
    to prevent additional downloads of the same wheel. - by
    @mayeut. (#2268)
  * Bugfixes
    + Fix AttributeError: 'bool' object has no attribute 'error' when
    creating a Python 2.x virtualenv on macOS - by moreati. (#2269)
    + Fix PermissionError: [Errno 1] Operation not permitted when
    creating a Python 2.x virtualenv on macOS/arm64 - by
    moreati. (#2271)
- changes from version 20.12.1:
  * Bugfixes
    + Try using previous updates of pip, setuptools & wheel when
    inside an update grace period rather than always falling back to
    embedded wheels - by @mayeut. (#2265)
    + New patch versions of pip, setuptools & wheel are now returned
    in the expected timeframe. - by @mayeut. (#2266)
    + Manual upgrades of pip, setuptools & wheel are not discarded by
    a periodic update - by @mayeut. (#2267)
- changes from version 20.12.0:
  * Features
    + Sign the python2 exe on Darwin arm64 - by @tmspicer. (#2233)
  * Bugfixes
    + Fix --download option - by @mayeut. (#2120)
    + Ugrade embedded setuptools to 60.2.0 from 60.1.1 - by
    @gaborbernat. (#2263)
- changes from version 20.11.2:
  * Bugfixes
    + Fix installation of pinned versions of pip, setuptools & wheel -
    by @mayeut. (#2203)
- changes from version 20.11.1:
  * Bugfixes
    + Bump embed setuptools to 60.1.1 from 60.1.0 - by
    @gaborbernat. (#2258)
- changes from version 20.11.0:
  * Features
    + Avoid deprecation warning from py-filelock argument - by
    @ofek. (#2237)
    + Upgrade embedded setuptools to 61.1.0 from 58.3.0 - by
    @gaborbernat. (#2240)
    + Drop the runtime dependency of backports.entry-points-selectable
  - by @hroncok. (#2246)
    + Fish: PATH variables should not be quoted when being set - by
    @hroncok. (#2248)
* Mon Dec  6 2021 dmueller@suse.com
- update to 20.10.0:
  * Special-case ``--prompt .`` to the name of the current directory
  * Add libffi-8.dll to pypy windows
  * Fixed path collision that could lead to a PermissionError or writing to system
    directories when using PyPy3.8
  * Upgrade embedded setuptools to ``58.3.0`` from ``58.1.0`` and pip to ``21.3.1`` from ``21.2.4``
  * Remove stray closing parenthesis in activate.bat
* Wed Sep 29 2021 code@bnavigator.de
- Update to 20.8.1
  * Fixed a bug where while creating a venv on top of an existing
    one, without cleaning, when seeded wheel version mismatch
    occurred, multiple .dist-info directories may be present,
    confounding entrypoint discovery
  * upgrade embedded setuptools to 58.1.0 and pip to 21.2.4
- Release to 20.8.0
  * Add nushell activation script
- Release 2.7.1
  * Fix unpacking dictionary items in PythonInfo.install_path
    (#2165)
- Fix and activate the test suite
- Update importlib* dependencies for older pythons
- Disable the python2 build because there is no
  python2-platformdirs on any distribution
* Tue Sep 14 2021 steven.kowalik@suse.com
- Add missing Requires on two modules.
- Drop no longer required appdirs Requires.
- Shift new BuildRequires to :test to avoid cycles.
* Wed Aug  4 2021 mcepl@suse.com
- Switch off tests, they are just broken.
* Tue Aug  3 2021 mcepl@suse.com
- Update to 20.7.0:
  - Removed xonsh activator due to this breaking fairly often the
    CI and lack of support from those packages maintainers,
    upstream is encouraged to continue supporting the project as
    a plugin
  - Support Python interpreters without distutils (fallback to
    syconfig in these cases)
  - Plugins now use 'selectable' entry points
  - add libffi-7.dll to the hard-coded list of dlls for PyPy
  - Drop python 3.4 support as it has been over 2 years since EOL
  - Use the better maintained platformdirs instead of appdirs
  - Built in discovery class is always preferred over plugin
    supplied classes.
  - On the programmatic API allow passing in the environment
    variable dictionary to use, defaults to os.environ if not
    specified
  - The builtin discovery takes now a --try-first-with argument
    and is first attempted as valid interpreters. One can use
    this to force discovery of a given python executable when the
    discovery order/mechanism raises errors
* Thu Mar 11 2021 mcepl@suse.com
- Actually switch off all activation tests, so we can shed all those
  dependencies.
* Mon Mar  8 2021 mcepl@suse.com
- Skip test_xonsh on platforms we don't carry xonsh.
* Sat Dec 19 2020 dmueller@suse.com
- update to 20.2.0:
  - Bump pip to ``20.3.1``, setuptools to ``51.0.0`` and wheel to ``0.36.1``
* Sun Dec  6 2020 code@bnavigator.de
- Require xonsh for testing of all Python 3 flavors in Tumbleweed
  gh#openSUSE/python-rpm-macros#66
- Update to 20.2.1
  * Optionally skip VCS ignore directive for entire virtualenv directory
  * Add ``--read-only-app-data`` option to allow for creation based on
    an existing app data cache which is non-writable
  * The python specification can now take one or more values, first found
    is used to create the virtual environment
* Thu Oct  8 2020 steven.kowalik@suse.com
- Update to 20.0.33:
  * Fix ``None`` type error in cygwin if POSIX path in dest - by :user:`danyeaw`. (`#1962 <https://github.com/pypa/virtualenv/issues/1962>`_)
  * Fix Python 3.4 incompatibilities (added back to the CI) - by :user:`gaborbernat`. (`#1963 <https://github.com/pypa/virtualenv/issues/1963>`_)
  * For activation scripts always use UNIX line endings (unless it's BATCH shell related) - by :user:`saytosid`. (`#1818 <https://github.com/pypa/virtualenv/issues/1818>`_)
  * Avoid spawning new windows when doing seed package upgrades in the background on Windows - by :user:`gaborbernat`. (`#1928 <https://github.com/pypa/virtualenv/issues/1928>`_)
  * Fix a bug that reading and writing on the same file may cause race on multiple processes. (`#1938 <https://github.com/pypa/virtualenv/issues/1938>`_)
  * Provide correct path for bash activator in cygwin or msys2 - by :user:`danyeaw`. (`#1940 <https://github.com/pypa/virtualenv/issues/1940>`_)
  * Relax importlib requirement to allow version<3 - by :user:`usamasadiq` (`#1953 <https://github.com/pypa/virtualenv/issues/1953>`_)
  * pth files were not processed on CPython2 if $PYTHONPATH was pointing to site-packages/ - by :user:`navytux`. (`#1959 <https://github.com/pypa/virtualenv/issues/1959>`_) (`#1960 <https://github.com/pypa/virtualenv/issues/1960>`_)
  * Fix test suite failing if run from system Python - by :user:`gaborbernat`. (`#1882 <https://github.com/pypa/virtualenv/issues/1882>`_)
  * Provide ``setup_logging`` flag to python API so that users can bypass logging handling if their application already
  * performs this - by :user:`gaborbernat`. (`#1896 <https://github.com/pypa/virtualenv/issues/1896>`_)
  * Use ``\n`` instead if ``\r\n`` as line separator for report (because Python already performs this transformation
  * automatically upon write to the logging pipe) - by :user:`gaborbernat`. (`#1905 <https://github.com/pypa/virtualenv/issues/1905>`_)
  * No longer preimport threading to fix support for `gpython <https://pypi.org/project/pygolang/#gpython>`_ and `gevent <https://www.gevent.org/>`_ - by :user:`navytux`. (`#1897 <https://github.com/pypa/virtualenv/issues/1897>`_)
  * Bump dependency ``distutils >= 0.3.1`` - by :user:`gaborbernat`. (`#1880 <https://github.com/pypa/virtualenv/issues/1880>`_)
  * Improve periodic update handling:
    + better logging output while running and enable logging on background process call (``_VIRTUALENV_PERIODIC_UPDATE_INLINE`` may be used to debug behaviour inline)
    + fallback to unverified context when querying the PyPi for release date,
    + stop downloading wheels once we reach the embedded version, by :user:`gaborbernat`. (`#1883 <https://github.com/pypa/virtualenv/issues/1883>`_)
  * Do not print error message if the application exists with ``SystemExit(0)`` - by :user:`gaborbernat`. (`#1885 <https://github.com/pypa/virtualenv/issues/1885>`_)
- Update Requires of python-distlib
- Drop tests.patch, included upstream.
* Tue Jul  7 2020 tchvatal@suse.com
- Add patch from upstream to fix one failing test:
  * tests.patch
* Fri Jul  3 2020 tchvatal@suse.com
- Add missing dependencies
- Skip online test test_seed_link_via_app_data
* Wed Jun 24 2020 dmueller@suse.com
- update to 20.0.25:
  * Fix that when the ``app-data`` seeders image creation fails the exception is silently ignored. Avoid two virtual environment creations to step on each oth
  ers toes by using a lock while creating the base images. By :user:`gaborbernat`. (`#1869 <https://github.com/pypa/virtualenv/issues/1869>`_)
  * Ensure that the seeded packages do not get too much out of date:
  +  More details under :ref:`wheels` - by :user:`gaborbernat`. (`#1821 <https://github.com/pypa/virtualenv/issues/1821>`_)
  * Upgrade embed wheel content:
  +  - ship wheels for Python ``3.9`` and ``3.10``
  +  - upgrade setuptools for Python ``3.5+`` from ``47.1.1`` to ``47.3.1``
  * Fix typo in ``setup.cfg`` - by :user:`RowdyHowell`. (`#1857 <https://github.com/pypa/virtualenv/issues/1857>`_)
  * Relax ``importlib.resources`` requirement to also allow version 2 - by :user:`asottile`. (`#1846 <https://github.com/pypa/virtualenv/issues/1846>`_)
  * Upgrade embedded setuptools to ``44.1.1`` for python 2 and ``47.1.1`` for python3.5+ - by :user:`gaborbernat`. (`#1855 <https://github.com/pypa/virtualenv/issues/1855>`_)
* Tue Jun  2 2020 dmueller@suse.com
- update to 20.0.21:
  - Fix virtualenv fails sometimes when run concurrently, ``--clear-app-data`` conflicts with :option:`clear` flag when
    abbreviation is turned on. To bypass this while allowing abbreviated flags on the command line we had to move it to
    :option:`reset-app-data` - by :user:`gaborbernat`. (`#1824 <https://github.com/pypa/virtualenv/issues/1824>`_)
  - Fix download fails with python 3.4 - by :user:`gaborbernat`. (`#1809 <https://github.com/pypa/virtualenv/issues/1809>`_)
  - Fixes older CPython2 versions use ``_get_makefile_filename`` instead of ``get_makefile_filename`` on ``sysconfig`` - by :user:`ianw`. (`#1810 <https://github.com/pypa/virtualenv/issues/1810>`_)
  - Fix download is ``True`` by default - by :user:`gaborbernat`. (`#1813 <https://github.com/pypa/virtualenv/issues/1813>`_)
  - Fail ``app-data`` seed operation when wheel download fails and better error message - by :user:`gaborbernat`. (`#1814 <https://github.com/pypa/virtualenv/issues/1814>`_)
  - Fix generating a Python 2 environment from Python 3 creates invalid python activator - by :user:`gaborbernat`. (`#1776 <https://github.com/pypa/virtualenv/issues/1776>`_)
  - Fix pinning seed packages via ``app-data`` seeder raised ``Invalid Requirement`` - by :user:`gaborbernat`. (`#1779 <https://github.com/pypa/virtualenv/issues/1779>`_)
  - Do not stop interpreter discovery if we fail to find the system interpreter for a executable during discovery
  - by :user:`gaborbernat`. (`#1781 <https://github.com/pypa/virtualenv/issues/1781>`_)
  - On CPython2 POSIX platforms ensure ``syconfig.get_makefile_filename`` exists within the virtual environment (this is used by some c-extension based libraries - e.g. numpy - for building) - by :user:`gaborbernat`. (`#1783 <https://github.com/pypa/virtualenv/issues/1783>`_)
  - Better handling of options :option:`copies` and :option:`symlinks`. Introduce priority of where the option is set
    to follow the order: CLI, env var, file, hardcoded. If both set at same level prefers copy over symlink. - by
    :user:`gaborbernat`. (`#1784 <https://github.com/pypa/virtualenv/issues/1784>`_)
  - Upgrade pip for Python ``2.7`` and ``3.5+`` from ``20.0.2`` to ``20.1`` - by :user:`gaborbernat`. (`#1793 <https://github.com/pypa/virtualenv/issues/1793>`_)
  - Fix CPython is not discovered from Windows registry, and discover pythons from Windows registry in decreasing order
    by version - by :user:`gaborbernat`. (`#1796 <https://github.com/pypa/virtualenv/issues/1796>`_)
  - Fix symlink detection for creators - by :user:`asottile` (`#1803 <https://github.com/pypa/virtualenv/issues/1803>`_)
  - Importing setuptools before cli_run could cause our python information query to fail due to setuptools patching
    ``distutils.dist.Distribution`` - by :user:`gaborbernat`. (`#1771 <https://github.com/pypa/virtualenv/issues/1771>`_)
* Thu Apr 16 2020 tchvatal@suse.com
- Update to 20.0.17:
  * minor fixes
  * update of embedded modules
* Thu Mar 19 2020 tchvatal@suse.com
- Update to 20.0.11:
  - Allow the test suite to pass even when called with the system Python - to help repackaging of the tool for Linux
    distributions -  by :user:`gaborbernat`. (`#1721 <https://github.com/pypa/virtualenv/issues/1721>`_)
  - Other minor fixes
* Fri Mar 13 2020 tchvatal@suse.com
- Update to 20.0.10:
  * Complete rewrite and redesign of the virtualenv package
* Fri Mar  6 2020 sleep_walker@opensuse.org
- update to 16.7.10
  * fix error printing in bailout for Python < 2.7
* Thu Feb  6 2020 mcalabkova@suse.com
- update to 16.7.9
  * upgrade setuptools from 41.4.0 to 42.0.2
  * fix virtualenv creation when --no-pip argument used.
* Tue Sep 17 2019 tchvatal@suse.com
- Use multibuild to avoid cycles with pytest
* Mon Sep 16 2019 tchvatal@suse.com
- Update to 16.7.5:
  * fix powershell activation when sourced (#1398)
  * fix regression - sh activation script not working under sh (only bash) (#1396)
  * activate.ps1 syntax and style updated to follow PSStyleAnalyzer rules (#1371)
  * Allow creating virtual environments for 3.xy. (#1385)
  * Report error when running activate scripts directly
  * Extend the LICENSE search paths list by lib64/pythonX.Y to support Linux vendors who install their Python to /usr/lib64/pythonX.Y
  * Raise an error if the target path contains the operating systems path separator (using this would break our activation scripts)
  * Drop Jython support
  * Add tests covering prompt manipulation during activation/deactivation, and harmonize behavior of all supported shells
* Mon Mar  4 2019 tchvatal@suse.com
- Update to 16.4.3:
  * Revert the symlink fix, causing debian packaging issues. (#1390)
  * Fix license() builtin by copying the LICENSE file into the virtualenv - by asottile. (#1317)
  * fixes the scenario where the python base install is symlinked with relative symlinks (#490)
  * Use importlib over imp in virtualenv.py for python >= 3.4 - by Anthony Sottile (#1293)
  * Copy or link PyPy header files instead of include directory itself (#1302)
  * Allow virtualenv creation with older pip not having config command correspondingly disabling configuration related features (such as pip cert setting) in this case. (#1303)
  * Use importlib over deprecated imp` in ``distutils/__init__.py for python 3 - by Anthony Sottile (#955)
  * Preserve cert option defined in pip.conf or environment variable. (#1273)
  * fixed a ResourceWarning: unclosed file in call_subprocess() - by Mickaël Schoentgen (#1277)
  * pre-import some built-in modules in site.py on PyPy according to PyPy's site.py - by microdog (#1281)
  * Copy files from sys.exec_prefix only if it is really different path than used prefix, bugfix for #1270 (#1282)
  * copyfile handles relative symlinks and symlinks to symlinks, avoiding problems when Python was installed using stow or homebrew. (#268)
  * Fix preserving of original path when using fish and a subshell. (#904)
  * Drop the source layout of the project, going back to how the source was laid out before 16.1.0. (#1241)
  * Fix bootstrap script generation broken with 16.0.0. Support now both CPython, pypy, jython. (#1244)
  * lib64 symlink is again relative (as was with < 16.1.0). (#1248)
* Tue Feb  5 2019 nicolas.bock@suse.com
- Version bump to 16.1.0:
  * Fixed documentation to use pypi.org and correct curl options; :issue:`1042`
  * bug fix: ensure prefix is absolute when creating a new virtual
    environment :issue:`1208`
  * upgrade setuptools from ``39.1.0`` to ``40.5.0``
  * upgrade wheel from ``0.31.1`` to ``0.32.2``
  * upgrade pip from ``10.0.1`` to ``18.1``
  * ``activate.csh`` does not use basename and handles newlines :issue:`1200`
  * fix failure to copy on platforms that use lib64 :issue:`1189`
  * enable tab-completion in the interactive interpreter by default,
    thanks to a new ``sys.__interactivehook__`` on Python 3 :issue:`967`
  * suppress warning of usage of the deprecated ``imp`` module :issue:`1238`
  * Drop support for Python 2.6.
  * Upgrade pip to 10.0.1.
  * Upgrade setuptools to 39.1.0.
  * Upgrade wheel to 0.31.1.
- Removed patch
  - pypa-virtualenv-1189.patch
* Sat Aug  4 2018 matwey.kornilov@gmail.com
- Add requires: python-setuptools (bsc#1127328)
    > virtualenv-3.6 --help
    Traceback (most recent call last):
    File "/usr/bin/virtualenv-3.6", line 6, in <module>
    from pkg_resources import load_entry_point
    ModuleNotFoundError: No module named 'pkg_resources'
* Sun Jul 22 2018 tchvatal@suse.com
- Enable tests, skip upstream failing one
* Fri Jul 20 2018 mwilck@suse.com
- Fix failure of virtualenv --always-copy (bsc#1102096):
  * pypa-virtualenv-1189.patch
* Wed Feb 21 2018 tbechtold@suse.com
- Add missing Requires for python (bsc#1081707)
* Mon Mar 27 2017 jmatejek@suse.com
- do not generate HTML documentation for packages that are indirect
  dependencies of Sphinx
  (see docs at https://virtualenv.readthedocs.org/ )
- move uninstall_alternatives to %%postun
* Thu Mar 16 2017 tbechtold@suse.com
- Merge python-virtualenv-doc.spec into python-virtualenv.spec
* Thu Mar 16 2017 tbechtold@suse.com
- update to 15.1.0:
  * Support Python 3.6.
  * Upgrade setuptools to 28.0.0.
  * Upgrade pip to 9.0.1.
  * Don't install pre-release versions of pip, setuptools, or wheel from PyPI.
- Switch to singlespec approach
* Tue Mar  8 2016 arun@gmx.de
- specfile:
  * update copyright
  * fix update-alternatives
- update to version 15.0.0:
  * Remove the virtualenv-N.N script from the package; this can no
    longer be correctly created from a wheel installation. Resolves
    [#851], #692
  * Remove accidental runtime dependency on pip by extracting
    certificate in the subprocess.
  * Upgrade setuptools 20.2.2.
  * Upgrade pip to 8.1.0.
- changes from version 14.0.6:
  * Upgrade setuptools to 20.0
  * Upgrade wheel to 0.29.0
  * Fix an error where virtualenv didn’t pass in a working ssl
    certificate for pip, causing “weird” errors related to ssl.
- changes from version 14.0.5:
  * Homogenize drive letter casing for both prefixes and
    filenames. #858
- changes from version 14.0.4:
  * Upgrade setuptools to 19.6.2
  * Revert ac4ea65; only correct drive letter case. Fixes #856, #815
- changes from version 14.0.3:
  * Upgrade setuptools to 19.6.1
- changes from version 14.0.2:
  * Upgrade setuptools to 19.6
  * Supress any errors from unset on different shells (PR #843)
  * Normalize letter case for prefix path checking. Fixes #837
- changes from version 14.0.1:
  * Upgrade from pip 8.0.0 to 8.0.2.
  * Fix the default of --(no-)download to default to downloading.
- changes from version 14.0.0:
  * BACKWARDS INCOMPATIBLE Drop support for Python 3.2.
  * Upgrade setuptools to 19.4
  * Upgrade wheel to 0.26.0
  * Upgrade pip to 8.0.0
  * Upgrade argparse to 1.4.0
  * Added support for python-config script (PR #798)
  * Updated activate.fish (PR #589) (PR #799)
  * Account for a site.pyo correctly in some python implementations
    (PR #759)
  * Properly restore an empty PS1 (#407)
  * Properly remove pydoc when deactivating
  * Remove workaround for very old Mageia / Mandriva linuxes (PR #472)
  * Added a space after virtualenv name in the prompt: (env) $PS1
  * Make sure not to run a –user install when creating the virtualenv
    (PR #803)
  * Remove virtualenv.py’s path from sys.path when executing with a
    new python. Fixes issue #779, #763 (PR #805)
  * Remove use of () in .bat files so Program Files (x86) works #35
  * Download new releases of the preinstalled software from PyPI when
    there are new releases available. This behavior can be disabled
    using --no-download.
  * Make --no-setuptools, --no-pip, and --no-wheel independent of each
    other.
* Wed Sep 16 2015 rhafer@suse.com
- update to version 13.1.2:
  * Upgrade pip to 7.1.2.
- additional changes from version 13.1.1
  * Upgrade pip to 7.1.1.
  * Upgrade setuptools to 18.2.
  * Make the activate script safe to use when bash is running with ``-u``.
- additional changes from version 13.1.0
  * Upgrade pip to 7.1.0
  * Upgrade setuptools to 18.0.1
- additional changes from version 13.0.3
  * Upgrade pip to 7.0.3
- additional changes from version 13.0.2
  * Upgrade pip to 7.0.2
  * Upgrade setuptools to 17.0
- additional changes from version 13.0.1
  * Upgrade pip to 7.0.1
- additional changes from version 13.0.0
  * Automatically install wheel when creating a new virutalenv. This can be
    disabled by using the ``--no-wheel`` option.
  * Don't trust the current directory as a location to discover files to install
    packages from.
  * Upgrade setuptools to 16.0.
  * Upgrade pip to 7.0.0.
* Wed Jul 29 2015 toddrme2178@gmail.com
- Split documentation into subpackage to avoid
  dependency loop
* Thu Apr  2 2015 benoit.monin@gmx.fr
- update to version 12.0.7:
  * Upgrade pip to 6.0.8
- additional changes from version 12.0.6:
  * Upgrade pip to 6.0.7
  * Upgrade setuptools to 12.0.5
- additional changes from version 12.0.5:
  * Upgrade pip to 6.0.6
  * Upgrade setuptools to 11.0
- additional changes from version 12.0.4:
  * Revert the fix to ``-p`` on Debian based pythons as it was
    broken in other situations.
  * Revert several sys.path changes new in 12.0 which were breaking
    virtualenv.
- additional changes from version 12.0.3:
  * Fix an issue where Debian based Pythons would fail when using
  - p with the host Python.
  * Upgrade pip to 6.0.3
- additional changes from version 12.0.2:
  * Upgraded pip to 6.0.2
- additional changes from version 12.0.1:
  * Upgraded pip to 6.0.1
- additional changes from version 12.0:
  * **PROCESS** Version numbers are now simply ``X.Y`` where the
    leading ``1`` has been dropped.
  * Split up documentation into structured pages
  * Now using pytest framework
  * Correct sys.path ordering for debian, issue #461
  * Correctly throws error on older Pythons, issue #619
  * Allow for empty $PATH, pull #601
  * Don't set prompt if $env:VIRTUAL_ENV_DISABLE_PROMPT is set for
    Powershell
  * Updated setuptools to 7.0
* Sat Nov  8 2014 ledest@gmail.com
- fix bashism in pre script
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 1.11.6
  * Updated setuptools to 3.6
  * Updated pip to 1.5.6
  * Updated documentation to use https://virtualenv.pypa.io/
* Sun Mar 30 2014 toddrme2178@gmail.com
- update to 1.11.4
  * Updated pip to 1.5.4
- update to 1.11.3
  * Updated setuptools to 2.2
  * Updated pip to 1.5.3
* Tue Feb 11 2014 dmueller@suse.com
- update to 1.11.2:
  * Fixed easy_install installed virtualenvs by updated pip to 1.5.2
  * Fixed an issue where pip and setuptools were not getting installed when using
  the ``--system-site-packages`` flag.
  * Updated setuptools to fix an issue when installed with easy_install
  * Fixed an issue with Python 3.4 and sys.stdout encoding being set to ascii
* Tue Jan  7 2014 speilicke@suse.com
- Update to version 1.11:
  + BACKWARDS INCOMPATIBLE Switched to using wheels for the bundled
    copies of setuptools and pip. Using sdists is no longer supported
  + BACKWARDS INCOMPATIBLE Modified the handling of --extra-search-dirs.
    This option now works like pip’s --find-links option, in that it
    adds extra directories to search for compatible wheels for pip and
    setuptools. The actual wheel selected is chosen based on version
    and compatibility, using the same algorithm as pip install setuptools.
  + Upgraded pip to v1.5
  + Upgraded setuptools to v1.4
- Symlink /usr/bin/virtualenv in buildroot (u-a warning) and ghost
  alternatives link on 12.3 or newer
* Fri Oct 11 2013 speilicke@suse.com
- Update to version 1.10.1:
  + **New Signing Key** Release 1.10.1 is using a different key than normal with
    fingerprint: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
  + Upgraded pip to v1.4.1
  + Upgraded setuptools to v0.9.8
* Mon Jul 29 2013 speilicke@suse.com
- Don't drop shipped setuptools / pip, they've been fetched from the
  interwebs previously. It doesn't make sense to use the (currently
  matching) system equivalents, it's meant to be self-contained
* Mon Jul 29 2013 speilicke@suse.com
- Use update-alternatives for parallel-installability with Python3 version
* Mon Jul 29 2013 speilicke@suse.com
- Update to version 1.10:
  + BACKWARDS INCOMPATIBLE Dropped support for Python 2.5. The minimum supported
    Python version is now Python 2.6.
  + BACKWARDS INCOMPATIBLE Using virtualenv.py as an isolated script (i.e.
    without an associated virtualenv_support directory) is no longer supported
    for security reasons and will fail with an error.
  + Along with this, --never-download is now always pinned to True, and is only
    being maintained in the short term for backward compatibility (Pull #412).
  + IMPORTANT Switched to the new setuptools (v0.9.7) which has been merged with
    Distribute again and works for Python 2 and 3 with one codebase. The
  - -distribute and --setuptools options are now no-op.
  + Updated to pip 1.4.
  + Added support for PyPy3k
  + Added the option to use a version number with the -p option to get the system
    copy of that Python version (Windows only)
  + Removed embedded ez_setup.py, distribute_setup.py and distribute_from_egg.py
    files as part of switching to merged setuptools.
  + Fixed --relocatable to work better on Windows.
  + Fixed issue with readline on Windows.
- Spec clean:
  + Depend on setuptools instead of distribute again
  + Package README.rst
  + Build HTML documentation and install it (instead of sources)
* Fri Mar  8 2013 alexandre@exatati.com.br
- Update to 1.9.1:
  * Updated to pip 1.3.1 that fixed a major backward incompatible
    change of parsing URLs to externally hosted packages that got
    accidentily included in pip 1.3.
- Aditional changes from 1.9
  * Unset VIRTUAL_ENV environment variable in deactivate.bat
    (Pull #364)
  * Upgraded distribute to 0.6.34.
  * Added --no-setuptools and --no-pip options (Pull #336).
  * Fixed Issue #373. virtualenv-1.8.4 was failing in cygwin
    (Pull #382).
  * Fixed Issue #378. virtualenv is now "multiarch" aware on
    debian/ubuntu (Pull #379).
  * Fixed issue with readline module path on pypy and OSX (Pull #374).
  * Made 64bit detection compatible with Python 2.5 (Pull #393).
* Tue Nov 27 2012 alexandre@exatati.com.br
- Update to 1.8.4:
  - Updated distribute to 0.6.31. This fixes #359 (numpy install
    regression) on UTF-8 platforms, and provides a workaround on
    other platforms: PYTHONIOENCODING=utf8 pip install numpy.
  - When installing virtualenv via curl, don't forget to filter
    out arguments the distribute setup script won't understand.
    Fixes #358.
  - Added some more integration tests.
* Sun Nov 25 2012 alexandre@exatati.com.br
- Update to 1.8.3:
  - Fixed readline on OS X. Thanks minrk
  - Updated distribute to 0.6.30 (improves our error reporting,
    plus new distribute features and fixes). Thanks Gabriel (g2p)
  - Added compatibility with multiarch Python (Python 3.3 for example).
    Added an integration test. Thanks Gabriel (g2p)
  - Added ability to install distribute from a user-provided egg,
    rather than the bundled sdist, for better speed. Thanks Paul Moore.
  - Make the creation of lib64 symlink smarter about already-existing
    symlink, and more explicit about full paths. Fixes #334 and #330.
    Thanks Jeremy Orem.
  - Give lib64 site-dir preference over lib on 64-bit systems, to
    avoid wrong 32-bit compiles in the venv. Fixes #328. Thanks Damien
    Nozay.
  - Fix a bug with prompt-handling in activate.csh in non-interactive
    csh shells. Fixes #332. Thanks Benjamin Root for report and patch.
  - Make it possible to create a virtualenv from within a Python 3.3
    pyvenv. Thanks Chris McDonough for the report.
  - Add optional --setuptools option to be able to switch to it in
    case distribute is the default (like in Debian).
* Thu Sep  6 2012 alexandre@exatati.com.br
- Update to 1.8.2:
  * Updated the included pip version to 1.2.1 to fix regressions
    introduced there in 1.2.
* Mon Sep  3 2012 alexandre@exatati.com.br
- Update to 1.8.1:
  * Fixed distribute version used with --never-download. Thanks
    michr for report and patch.
  * Fix creating Python 3.3 based virtualenvs by unsetting the
    __PYVENV_LAUNCHER__ environment variable in subprocesses.
* Sat Sep  1 2012 alexandre@exatati.com.br
- Update to 1.8:
  - Dropped support for Python 2.4 The minimum supported Python
    version is now Python 2.5.
  - Fix --relocatable on systems that use lib64. Fixes #78. Thanks
    Branden Rolston.
  - Symlink some additional modules under Python 3. Fixes #194.
    Thanks Vinay Sajip, Ian Clelland, and Stefan Holek for the report.
  - Fix --relocatable when a script uses __future__ imports. Thanks
    Branden Rolston.
  - Fix a bug in the config option parser that prevented setting
    negative options with environemnt variables. Thanks Ralf Schmitt.
  - Allow setting --no-site-packages from the config file.
  - Use /usr/bin/multiarch-platform if available to figure out the
    include directory. Thanks for the patch, Mika Laitio.
  - Fix install_name_tool replacement to work on Python 3.X.
  - Handle paths of users' site-packages on Mac OS X correctly
    when changing the prefix.
  - Updated the embedded version of distribute to 0.6.28 and pip
    to 1.2.
* Fri Jun 22 2012 alexandre@exatati.com.br
- Update to 1.7.2:
  - Updated to distribute 0.6.27.
  - Fix activate.fish on OS X. Fixes #8. Thanks David Schoonover.
  - Create a virtualenv-x.x script with the Python version when
    installing, so virtualenv for multiple Python versions can be
    installed to the same script location. Thanks Miki Tebeka.
  - Restored ability to create a virtualenv with a path longer than
    78 characters, without breaking creation of virtualenvs with
    non-ASCII paths. Thanks, Bradley Ayers.
  - Added ability to create virtualenvs without having installed
    Apple's developers tools (using an own implementation of
    install_name_tool). Thanks Mike Hommey.
  - Fixed PyPy and Jython support on Windows. Thanks Konstantin
    Zemlyak.
  - Added pydoc script to ease use. Thanks Marc Abramowitz. Fixes
    [#149].
  - Fixed creating a bootstrap script on Python 3. Thanks Raul
    Leal. Fixes #280.
  - Fixed inconsistency when having set the PYTHONDONTWRITEBYTECODE
    env var with the --distribute option or the
    VIRTUALENV_USE_DISTRIBUTE env var. VIRTUALENV_USE_DISTRIBUTE
    is now considered again as a legacy alias.
* Fri Feb 17 2012 alexandre@exatati.com.br
- Update to 1.7.1.2:
  * Fixed minor issue in --relocatable. Thanks, Cap Petschulat.
- Aditional changes from 1.7.1.1:
  * Bumped the version string in virtualenv.py up, too.
  * Fixed rST rendering bug of long description.
* Wed Nov 30 2011 alexandre@exatati.com.br
- Update to 1.7:
  - Updated embedded Distribute release to 0.6.24. Thanks Alex
    Grönholm.
  - Made --no-site-packages behavior the default behavior. The
  - -no-site-packages flag is still permitted, but displays a
    warning when used. Thanks Chris McDonough.
  - New flag: --system-site-packages; this flag should be passed
    to get the previous default global-site-package-including
    behavior back.
  - Added ability to set command options as environment variables
    and options in a virtualenv.ini file.
  - Fixed various encoding related issues with paths. Thanks
    Gunnlaugur Thor Briem.
  - Made virtualenv.py script executable.
* Thu Jul 21 2011 alexandre@exatati.com.br
- Update to 1.6.4:
  * Restored ability to run on Python 2.4, too.
* Tue Jul 19 2011 saschpe@suse.de
- Spec file cleanup:
  * Remove she-bang line from non-executable script (rpmlint warning)
  * Remove in-tree libraries (setuptools, pip & distribute)
  * Don't package PKG-INFO but AUTHORS.txt and LICENSE.txt
* Sun Jul 17 2011 alexandre@exatati.com.br
- Update to 1.6.3:
  * Restored ability to run on Python < 2.7.
- Aditional changes from 1.6.2:
  * Updated embedded distribute release to 0.6.19.
  * Updated embedded pip release to 1.0.2.
  * Fixed #141 - Be smarter about finding pkg_resources when using the
    non-default Python intepreter (by using the -p option).
  * Fixed #112 - Fixed path in docs.
  * Fixed #109 - Corrected doctests of a Logger method.
  * Fixed #118 - Fixed creating virtualenvs on platforms that use the
    "posix_local" install scheme, such as Ubuntu with Python 2.7.
  * Add missing library to Python 3 virtualenvs (_dummy_thread).
* Mon May  2 2011 alexandre@exatati.com.br
- Update to 1.6.1:
  * Start to use git-flow.
  * Added support for PyPy 1.5
  * Fixed #121 -- added sanity-checking of the -p argument. Thanks Paul Nasrat.
  * Added progress meter for pip installation as well as setuptools. Thanks Ethan
    Jucovy.
  * Added --never-download and --search-dir options. Thanks Ethan Jucovy.
* Wed Apr 13 2011 alexandre@exatati.com.br
- Update to 1.6:
  * Added Python 3 support! Huge thanks to Vinay Sajip and Vitaly Babiy.
  * Fixed creation of virtualenvs on Mac OS X when standard library modules
    (readline) are installed outside the standard library.
  * Updated bundled pip to 1.0.
- Regenerate spec file with py2pack.
* Sun Sep 19 2010 alexandre@exatati.com.br
- Update to 1.5.1:
  - Added ``_weakrefset`` requirement for Python 2.7.1.
  - Fixed Windows regression in 1.5.
* Wed Sep 15 2010 alexandre@exatati.com.br
- Update to 1.5:
  - Include pip 0.8.1.
  - Add support for PyPy.
  - Uses a proper temporary dir when installing environment requirements.
  - Add --prompt option to be able to override the default prompt prefix.
  - Fix an issue with --relocatable on Windows.
  - Fix issue with installing the wrong version of distribute.
  - Add fish and csh activate scripts.
* Fri May 28 2010 alexandre@exatati.com.br
- Update to 1.4.9:
  * Include pip 0.7.2.
* Fri Apr 23 2010 alexandre@exatati.com.br
- Update to 1.4.8:
  * Fix for Mac OS X Framework builds that use
    ``--universal-archs=intel``
  * Fix ``activate_this.py`` on Windows.
  * Allow ``$PYTHONHOME`` to be set, so long as you use ``source
    bin/activate`` it will get unset; if you leave it set and do not
    activate the environment it will still break the environment.
  * Include pip 0.7.1.
* Mon Apr 19 2010 alexandre@exatati.com.br
- Update to 1.4.7:
  * Include pip 0.7.
* Wed Mar 31 2010 alexandre@exatati.com.br
- Update to 1.4.6
  * Allow ``activate.sh`` to skip updating the prompt (by setting
    ``$VIRTUAL_ENV_DISABLE_PROMPT``).
- Spec file cleaned with spec-cleaner.
* Mon Mar 15 2010 alexandre@exatati.com.br
- Added python-setuptools as Requires;
- Generated changes file from spec file;
- Removed old tarballs;
- Update to 1.4.5
  - Include pip 0.6.3
- Aditional changes from 1.4.4:
  - Include pip 0.6.2 and Distribute 0.6.10
  - Create the virtualenv script even when Setuptools isn’t installed
  - Fix problem with virtualenv --relocate when bin/ has subdirectories
    (e.g., bin/.svn/); from Alan Franzoni.
  - If you set $VIRTUALENV_USE_DISTRIBUTE then virtualenv will use
    Distribute by default (so you don’t have to remember to use --distribute).
* Sat Nov 21 2009 cfarrell1980@gmail.com
- 1.4.3
  * Include pip 0.6.1
* Mon Nov  9 2009 cfarrell1980@gmail.com
- Update to 1.4
  * Updated setuptools to 0.6c11
  * Added the --distribute option
  * Fixed packaging problem of support-files
* Tue Mar  3 2009 cfarrell1980@gmail.com
- Update to 1.3.2
  - Remove the [install] prefix = ... setting from virtualenv distutils.cfg as has been causing problems for a lot of people, in rather obscure ways.
  - If you use a boot script it will attempt to import virtualenv and find a pre-downloaded Setuptools egg using that.
  - Added platform-specific paths, like /usr/lib/pythonX.Y/plat-linux2
* Wed Nov  5 2008 cfarrell1980@gmail.com
- Initial import and build - 1.3
